@@ -74,14 +74,14 @@ def validate_notebook_directory(
     if treebeard_env.project_id is None:
         click.echo(
             click.style(
-                "This library will not function without credentials.\nPlease email alex@treebeard.io to obtain an API key then run `treebeard configure`",
-                fg="red",
-            )
+                "No account config detected! Please run treebeard configure", fg="red",
+            ),
+            err=True,
         )
 
     if not os.path.exists(treebeard_config.notebook):
         fatal_exit(
-            f"Cannot run non-existent notebook '{treebeard_config.notebook}', are you missing a treebeard.yaml file?"
+            f"Cannot run non-existent notebook '{treebeard_config.notebook}', you should be in a project directory with a treebeard.yaml file"
         )
 
 
